@@ -31,13 +31,8 @@ SeqQualEntry = namedtuple('Entry', 'header sequence quality')
 class FastaError(ValueError):
     pass
 
-#Compatibility with Python 3
-import sys
-if sys.version_info[0] > 2:
-    import _io
-    file = _io.TextIOWrapper
 
-class FastaFile(file):
+class FastaFile(io.BufferedReader):
     """ FASTA file.
     The default iterator will go through the entries in the file (not the rows). 
     """
@@ -49,7 +44,7 @@ class FastaFile(file):
 class FastabError(ValueError):
     pass
 
-class FastabFile(file):
+class FastabFile(io.BufferedReader):
     """ FASTAB file.
     The default iterator will go through the entries in the file (not the rows).
     """
@@ -66,7 +61,7 @@ class FastabFile(file):
         - fout: FASTAB output file
         """
 
-        if not isinstance(fin, file):
+        if not isinstance(fin, io.BufferedReader):
             close_fin = True
             fin = fasta.FastaFile(fn_in)
         else:
