@@ -14,26 +14,20 @@ class FastqError(ValueError):
 #Compatibility with Python 3
 import sys
 _python2 = sys.version_info[0] == 2
-if sys.version_info[0] > 2:
-    import io
-    file = io.BufferedReader
 
 if _python2:
     import itertools
     zip = itertools.izip
 
 
-class FastqFile(file):
+class FastqFile(io.BufferedReader):
     """ FASTQ file.
     The default iterator will go through the entries in the file (not the rows) 
     """
 
     def __init__(self, filename, **kwargs):
-        if _python2:
-            super(FastqFile, self).__init__(filename, **kwargs)
-        else:
-            stream = io.FileIO(filename)
-            super(FastqFile, self).__init__(stream, **kwargs)
+        stream = io.FileIO(filename)
+        super(FastqFile, self).__init__(stream, **kwargs)
 
     def __iter__(self):
         wrap = io.OpenWrapper(self.fileno(), closefd = False)
