@@ -29,11 +29,11 @@ class IntervalListTestCase(unittest.TestCase):
 
     def test_initValid(self):
         itl = intervals.IntervalList()
-        self.assertEquals(0, len(itl))
+        self.assertEqual(0, len(itl))
         it1 = intervals.Interval(1, 7)
         it2 = intervals.Interval(3, 10)
         itl = intervals.IntervalList((it1, it2))
-        self.assertEquals(2, len(itl))
+        self.assertEqual(2, len(itl))
 
     def test_initInvalid(self):
         it1 = intervals.Interval(1, 7)
@@ -44,16 +44,16 @@ class IntervalListTestCase(unittest.TestCase):
     def test_minmax(self):
         itl = self.itl
         ir = itl.minmax()
-        self.assertEquals(1, ir.begin)
-        self.assertEquals(16, ir.end)
+        self.assertEqual(1, ir.begin)
+        self.assertEqual(16, ir.end)
 
     def test_collapse(self):
         itl = self.itl
         itl.sort()
         itl_c = intervals.IntervalList(intervals.IntervalList.collapse_iter(itl))
-        self.assertEquals(2, len(itl_c))
-        self.assertEquals(1, itl_c[0].begin)
-        self.assertEquals(10, itl_c[0].end)
+        self.assertEqual(2, len(itl_c))
+        self.assertEqual(1, itl_c[0].begin)
+        self.assertEqual(10, itl_c[0].end)
 
     def test_depthfilter(self):
         vals = ((1, 7), (2, 8), (3, 10), (12, 16), (11, 15),
@@ -62,17 +62,17 @@ class IntervalListTestCase(unittest.TestCase):
         itl.sort()
         tmp = intervals.IntervalList.depthfilter_iter(itl, 2)
         itl_f = intervals.IntervalList(tmp)
-        self.assertEquals(2, len(itl_f))
-        self.assertEquals(2, itl_f[0].begin)
-        self.assertEquals(8, itl_f[0].end)
-        self.assertEquals(12, itl_f[1].begin)
-        self.assertEquals(15, itl_f[1].end)
+        self.assertEqual(2, len(itl_f))
+        self.assertEqual(2, itl_f[0].begin)
+        self.assertEqual(8, itl_f[0].end)
+        self.assertEqual(12, itl_f[1].begin)
+        self.assertEqual(15, itl_f[1].end)
 
         tmp = intervals.IntervalList.depthfilter_iter(itl, 3)
         itl_f = intervals.IntervalList(tmp)
-        self.assertEquals(1, len(itl_f))
-        self.assertEquals(3, itl_f[0].begin)
-        self.assertEquals(7, itl_f[0].end)
+        self.assertEqual(1, len(itl_f))
+        self.assertEqual(3, itl_f[0].begin)
+        self.assertEqual(7, itl_f[0].end)
 
 
         
