@@ -29,7 +29,7 @@ def _stream_factory(ll_stream, extension):
         ValueError("stream without a known extension: %s" % extension)
     return stream
 
-def open(filename, mode="rb"):
+def open(filename, mode="rb", buffering=int(2**23)):
     """ Factory guessing the format from the file extension. """
     fn = filename.lower()
     tmp = fn.split(os.path.sep)[-1]
@@ -40,18 +40,24 @@ def open(filename, mode="rb"):
     # AFAIK, the only Python interface to BGZF is in biopython.
     compression = None
     if len(tmp) > 1 and tmp[-1] == 'gz':
-        ll_stream  = gzip.open(filename, mode=mode)
+        #fh = __builtins__['open'](filename, mode=mode, 
+        #                          buffering=buffering)
+        fh = filename
+        ll_stream  = gzip.open(fh, mode=mode)
         compression = tmp.pop()
         stream = _stream_factory(ll_stream, tmp[-1])
     elif len(tmp) > 1 and tmp[-1] == 'bz2':
-        ll_stream = bz2.open(filename, mode=mode)
+        fh = __builtins__['open'](filename, mode=mode, 
+                                  buffering=buffering)
+        ll_stream = bz2.open(fh, mode=mode)
         compression = tmp.pop()
         stream = _stream_factory(ll_stream, tmp[-1])
     elif tmp[-1] in BAM_SUFFIXES:
         from . import bam
         stream = bam.BamFile(filename, "rb")
     else:
-        ll_stream = __builtins__['open'](filename, mode=mode)
+        ll_stream = __builtins__['open'](filename, mode=mode, 
+                                         buffering=buffering)
         stream = _stream_factory(ll_stream, tmp[-1])
     
     return stream
